# This program is distributed under the terms of the
# GNU General Public License, version 2.
#
# Nekorum is forum additional plugin for MTOS/MT4.1 later.
# Original Copyright (c) 2008 nekotama (http://nekotama.org/)
#
# $Id: Util.pm 109 2008-05-24 10:16:34Z nekotama $

package Nekorum::CMS::Util;

use strict;

use MT;
use Nekorum::Util;

sub _view_template {
	my $app = shift;

	my $blog_id = $app->param('blog_id') or $app->errtrans('Invalid parameter.');
	my $entry_id = $app->param('entry_id') or undef;
	my $category_id = $app->param('category_id') or undef;
	my $author_id = $app->param('author_id') or undef;
	my $comment_id = $app->param('comment_id') or undef;
	
	my $templ_name = $app->param('tmpl') or $app->errtrans('Invalid parameter.');
	my $session = $app->param('session') or undef;
	my $author;
	
	my %param = $app->param_hash;
	
	# author session
	if($session){
		$author = Nekorum::Util->_get_author($app);
		return $app->errtrans("Session timeout.") unless($author);
	} else {
		# load blog
		require MT::Author;
		$author = MT::Author->load($author_id) if($author_id);
	}

	# load blog
	require MT::Blog;
	my $blog = MT::Blog->load($blog_id) if($blog_id);

	# load entry
	require MT::Entry;
	my $entry = MT::Entry->load($entry_id) if($entry_id);

	# load category
	require MT::Category;
	my $category = MT::Category->load($category_id) if($category_id);

	# load comment
	require MT::Comment;
	my $comment = MT::Comment->load($comment_id) if($comment_id);

	# load template
	require MT::Template;
	my $tmpl = MT::Template->load({ blog_id => $blog_id, type => 'custom', name => $templ_name}) or return $app->errtrans("Load template error.");

	require MT::Template::Context;
	my $ctx = MT::Template::Context->new;
	my %cond;
	$ctx->stash('blog', $blog);
	$ctx->stash('entry', $entry) if($entry);
	$ctx->stash('category', $category) if($category);
	$ctx->stash('author', $author) if($author);
	$ctx->stash('comment', $comment) if($comment);

	my ($name, $value);
	while (($name, $value) = each(%param)){
		$ctx->var($name,$value);
	}

	my $output = $tmpl->build($ctx, \%cond) or return $tmpl->errstr;
	return $output;
}

sub _set_script_js {
  local $SIG{__WARN__} = sub { };
  my $app = shift;

  my $blog_id = $app->param('blog_id');

  # author session
  my $author = Nekorum::Util->_get_author($app);
  my $author_id = ($author) ? $author->id : -1;
  my $output = "var nekorum_author_id = $author_id;\n";

	if($author){
	  my $user_id = sprintf("%08d", $author_id);
		my @categories;
		my $id = 1;
		
	  # load entry
	  require MT::Entry;
	  my @entries = MT::Entry->load({blog_id => $blog_id});
		foreach my $entry (@entries){
			my $entry_id = $entry->id;
			if(index($entry->nekorum_mark, $user_id)){
				$output .= "var nekorum_mark_$entry_id = 0;\n";
				my $category = $entry->category;
				my $category_id = $category->id;
				push(@categories, $category_id) unless(grep(/$category_id/, @categories));
			} else {
				$output .= "var nekorum_mark_$entry_id = 1;\n";
			}
		}
		foreach my $category (sort(@categories)){
			for(my $i = $id; $i < $category; $i++){
				$output .= "var nekorum_mark_cat_$i = 1;\n";
			}
			$id = $category+1;
			$output .= "var nekorum_mark_cat_$category = 0;\n";
		}
	}
	$output .= <<JAVA;
function hide_commenter(element, author){
	if(nekorum_author_id==author) element.style.display = 'inline';
	else element.style.display = 'none';
}

function hide_author(element, author){
	if(nekorum_author_id==author) element.style.display = 'inline';
	else element.style.display = 'none';
}

JAVA
  $app->{no_print_body} = 1;
 	$app->send_http_header("text/javascript");
  $app->print("$output");

	return undef;
}

1;